@@ -1,3 +1,6 @@
+from .miniscreen import Miniscreen, MiniscreenButton
+
+# Deprecated:
 from .oled import OLED
 from .buttons import (
     Buttons,
